Security Advisories (1)
CVE-2025-40929 (2025-09-08)

Cpanel::JSON::XS before version 4.40 for Perl has an integer buffer overflow causing a segfault when parsing crafted JSON, enabling denial-of-service attacks or other unspecified impact

NAME

Cpanel::JSON::XS::Boolean - true and false values

SYNOPSIS

# do not "use" yourself

See "true, false" in Cpanel::JSON::XS

DESCRIPTION

This module exists only to provide overload resolution for Storable and similar modules and interop with JSON::XS booleans. See Cpanel::JSON::XS for more info about this class.

AUTHOR

Marc Lehmann <schmorp@schmorp.de>
http://home.schmorp.de/